@@ -54,6 +54,34 @@ class DcdbClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CancelDcnJob(self, request):
+        """取消DCN同步
+
+        :param request: Request instance for CancelDcnJob.
+        :type request: :class:`tencentcloud.dcdb.v20180411.models.CancelDcnJobRequest`
+        :rtype: :class:`tencentcloud.dcdb.v20180411.models.CancelDcnJobResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("CancelDcnJob", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CancelDcnJobResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CloneAccount(self, request):
         """本接口（CloneAccount）用于克隆实例账户。
 
@@ -562,7 +590,7 @@ class DcdbClient(AbstractClient):
 
 
     def DescribeDCDBUpgradePrice(self, request):
-        """本接口（DescribeDCDBUpgradePrice）用于查询升级分布式数据库实例价格。
+        """本接口（DescribeDCDBUpgradePrice）用于查询变配分布式数据库实例价格。
 
         :param request: Request instance for DescribeDCDBUpgradePrice.
         :type request: :class:`tencentcloud.dcdb.v20180411.models.DescribeDCDBUpgradePriceRequest`
